Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Datetime ¶
type Datetime interface {
// FormatDate is a function to format a received date according to the custom parameter 'format'
FormatDate(date string, format string) (string, error)
// FormatDatetime is a function to format a received date according to the custom parameter 'format'
FormatDatetime(date time.Time, format string) string
// DatetimeNow is a function to get current date and time and format according to custom parameter 'format'
GetDateNow(format string) string
}
func NewDatetime ¶
func NewDatetime() Datetime
Click to show internal directories.
Click to hide internal directories.